@@ -52,4 +52,6 @@ STOCK_TRADE_CALENDAR_TABLE_NAME = "stock_trade_calendar_table"
 STOCK_TONGHUASHUN_INDEX_TABLE_NAME = "stock_tonghuashun_index_table" # 同花顺概念和行业指数
 STOCK_TONGHUASHUN_INDEX_MEMBER_TABLE_NAME = "stock_tonghuashun_index_member_table" # 同花顺概念板块成分
 STOCK_CHIP_YARDSTICK_QUOTIENT_TABLE_NAME= "chip_yardstick_quotient_table"
-STOCK_TOP_INSTITUTION_TABLE_NAME = "stock_top_institution_table"
\ No newline at end of file
+STOCK_TOP_INSTITUTION_TABLE_NAME = "stock_top_institution_table"
+STOCK_INDEX_BASIC_INFO_TABLE_NAME = "stock_index_basic_table"
+STOCK_INDEX_DAILY_TABLE_NAME = "stock_index_daily_table"
\ No newline at end of file
