@@ -69,7 +69,7 @@ class mysqlOps:
     - port
         数据库端口，默认为3306
     """
-    def __init__(self, database, host=os.getenv('MYSQL_HOST'), user=os.getenv('MYSQL_USER'), password=os.getenv('MYSQL_PASSWORD'), port=int(os.getenv('MYSQL_PORT'))):
+    def __init__(self, database, host=os.getenv('MYSQL_HOST'), user=os.getenv('MYSQL_USER'), password=os.getenv('MYSQL_PASSWORD'), port=int(os.getenv('MYSQL_PORT')), log_level = logging.WARNING):
         signal.signal(signal.SIGINT, self.signal_exit)
         atexit.register(self.cleanUp)
         self.__config_logging()
@@ -120,10 +120,11 @@ class mysqlOps:
             try:
                 cursor.execute(sql_cmd)
                 db.commit()
+                self.__logger.debug("指定MySQL命令成功")
                 return cursor.fetchall()
             except Exception as e:
-                db.rollback()
                 self.__logger.error("指定MySQL命令失败：SQL = " + sql_cmd + ", 错误信息：" + str(e))
+                db.rollback()
                 raise e
             finally:
                 db.close()
@@ -406,6 +407,7 @@ class mysqlOps:
             self.__logger.error("从" + table_name + "请求数据失败，SQL = " + sql + "，错误信息：" + str(e))
             return False, str(e)
         else:
+            self.__logger.debug("query succeed!, res = " + str(res))
             return True, res
 
     def update(self, table_name, kv_dict, filter_condition):
