@@ -7,6 +7,10 @@ import pandas as pd
 from QuantDataCollector.Utils.mysql_utils import mysqlOps
 from QuantDataCollector.Global.settings import *
 from QuantDataCollector.Utils.file_utils import mkdir
+from decimal import Decimal, getcontext
+
+# 设置精度（默认28位，可调整）
+getcontext().prec = 5  # 根据需求调整精度位数
 
 class DataCollectorError(Exception):  # 继承自 Exception 基类
     """自定义异常的说明文档"""
@@ -20,6 +24,22 @@ logging_type_map = {
     "critical": logging.CRITICAL,
 }
 
+def calculateForwardAdjustedPrice(price_list, adjust_factor_list, std_adj_factor):
+    forwardAdjPriceList = []
+    if len(price_list) != len(adjust_factor_list):
+        # 价格的数目和复权因子的数目必须一致
+        return forwardAdjPriceList
+    if std_adj_factor == 0:
+        #除数不能为0
+        return forwardAdjPriceList
+    for i, adj_factor in enumerate(adjust_factor_list):
+        price = Decimal(price_list[i])
+        current_adj_factor = Decimal(adj_factor)
+        std_adj_factor = Decimal(std_adj_factor)
+        forwardAdjPriceList.append(float(price * current_adj_factor / std_adj_factor))
+    return forwardAdjPriceList
+
+
 class DataCollector:
 
     def __init__(self,logging_level = "warning"):
@@ -110,8 +130,10 @@ class DataCollector:
 
     """
     获取日线数据
+    这里还会计算前复权价格，需要指定前复权的基准日期，，如果不指定则不返回前复权
+    基准日期不一定处在start_date和end_date之间
     """
-    def get_daily(self, code=None, date=None, start_date=None, end_date=None):
+    def get_daily(self, code=None, date=None, start_date=None, end_date=None, fap_std_day = None):
         self.__logger.info("get_daily: code = " + str(code) + ", date = " + str(date) + ", start_date = " + str(start_date) + ", end_date = " + str(end_date))
         filter = "1 = 1"
         if code:
@@ -128,6 +150,34 @@ class DataCollector:
         res, data = self.db.query(STOCK_DAILY_TABLE_NAME, columns, filter)
         if res:
             df = pd.DataFrame(data, columns=columns)
+            if fap_std_day != None:
+                try:
+                    std_adj_factor = self.get_adjust_factor(code = code, date = fap_std_day)
+                    std_adj_factor = float(std_adj_factor["adj_factor"].values[0])
+                except Exception as e:
+                    raise DataCollectorError("获取基准日复权因子失败，错误信息：" + str(e))
+                
+                adjust_factors = self.get_adjust_factor(code = code, date = date, start_date = start_date, end_date = end_date)
+                adjusted_open_prices = calculateForwardAdjustedPrice(df['open'].values,adjust_factors["adj_factor"].values, std_adj_factor=std_adj_factor)
+                adjusted_close_prices = calculateForwardAdjustedPrice(df['close'].values,adjust_factors["adj_factor"].values, std_adj_factor=std_adj_factor)
+                adjusted_high_prices = calculateForwardAdjustedPrice(df['high'].values,adjust_factors["adj_factor"].values, std_adj_factor=std_adj_factor)
+                adjusted_low_prices = calculateForwardAdjustedPrice(df['low'].values,adjust_factors["adj_factor"].values, std_adj_factor=std_adj_factor)
+                if len(adjusted_open_prices) != 0:
+                    df["fa_open"] = adjusted_open_prices
+                else:
+                    self.__logger.error("前复权开盘价计算失败")
+                if len(adjusted_close_prices) != 0:
+                    df["fa_close"] = adjusted_close_prices
+                else:
+                    self.__logger.error("前复权收盘价计算失败")
+                if len(adjusted_high_prices) != 0:
+                    df["fa_high"] = adjusted_high_prices
+                else:
+                    self.__logger.error("前复权最高价计算失败")
+                if len(adjusted_low_prices) != 0:
+                    df["fa_low"] = adjusted_low_prices
+                else:
+                    self.__logger.error("前复权最低价计算失败")
             return df
         else:
             self.__logger.error("从数据库获取历史日线失败：" + str(data))
@@ -347,6 +397,49 @@ class DataCollector:
         else:
             self.__logger.error("从数据库获取龙虎榜数据失败：" + str(data))
             raise DataCollectorError("从数据库获取龙虎榜数据失败，错误信息：" + str(data))
+    def get_index_basic(self, index_code_list = None):
+        self.__logger.info("get_index_basic: index_code_list = " + str(index_code_list))
+        filter = "1 = 1"
+        if index_code_list is not None:
+            filter += " AND index_code in ("
+            for index_code in index_code_list:
+                filter += "'" + index_code + "',"
+            filter = filter[:-1] + ")"
+
+        res, data = self.db.query(STOCK_INDEX_BASIC_INFO_TABLE_NAME, None, filter)
+        if res:
+            columns = ['index_code', 'name', 'fullname','market','publisher','index_type', 'category','base_date', 'base_point','list_date', 'weight_rule', 'description', 'exp_date']
+            df = pd.DataFrame(data, columns=columns)
+            return df
+        self.__logger.error("获取指数基本信息失败，错误信息" + str(data))
+        raise DataCollectorError("获取指数基本信息失败，错误信息：" + str(data))
+
+    def get_index_daily(self, index_code_list=None, date=None, start_date=None, end_date=None):
+        self.__logger.info("get_index_daily: index_code_list = " + str(index_code_list) + ", date = " + str(date) + ", start_date = " + str(start_date) + ", end_date = " + str(end_date))
+        filter = "1 = 1"
+        if index_code_list is not None:
+            filter += " AND index_code in ("
+            for index_code in index_code_list:
+                filter += "'" + index_code + "',"
+            filter = filter[:-1] + ")"
+
+        if date:
+            filter += " AND date = '" + date + "'"
+
+        if start_date:
+            filter += " AND date >= '" + start_date + "'"
+
+        if end_date:
+            filter += " AND date <= '" + end_date + "'"
+        columns = ['index_code', 'date', 'close', 'high', 'low', 'open','pre_close','chg','pct_chg', 'vol', 'amount']
+        res, data = self.db.query(STOCK_INDEX_DAILY_TABLE_NAME, columns, filter)
+        if res:
+            df = pd.DataFrame(data, columns=columns)
+            return df
+        else:
+            self.__logger.error("从数据库获取指数日线数据失败：" + str(data))
+            raise DataCollectorError("从数据库获取指数日线数据失败，错误信息：" + str(data))
+
 
 if __name__ == '__main__':
     data_collector = DataCollector()
\ No newline at end of file
